Package: BioImageDbs
Type: Package
Title: Bio- and biomedical imaging dataset for machine learning and
        deep learning (for ExperimentHub)
Version: 1.21.0
Encoding: UTF-8
Authors@R: c(
    person (given = "Satoshi", family = "Kume",
    role = c("aut", "cre"), 
    email = "satoshi.kume.1984@gmail.com",
    comment = c(ORCID = "0000-0001-7481-2843")),
    person(given = "Kozo", family = "Nishida",
    role = c("aut"),
    email = "kozo.nishida@gmail.com",
    comment = c(ORCID = "0000-0001-8501-7319"))
    )
Depends: R (>= 4.1.0)
Imports: ExperimentHub, AnnotationHub, markdown, rmarkdown, EBImage,
        magick, magrittr, filesstrings, animation, einsum
Suggests: knitr, BiocStyle, purrr
Description: The package provides a bioimage dataset for 
    the image analysis using machine learning and deep learning.
    The dataset includes microscopy imaging data with supervised labels.
    The data is provided as R list data that can be loaded to Keras/tensorflow 
    in R.
VignetteBuilder: knitr
License: Artistic-2.0
URL: https://kumes.github.io/BioImageDbs/
LazyLoad: yes
biocViews: ExperimentHub, ExperimentData, CellCulture, Tissue
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/BioImageDbs
git_branch: devel
git_last_commit: 5064eca
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 15:29:44 UTC; biocbuild
Author: Satoshi Kume [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7481-2843>),
  Kozo Nishida [aut] (ORCID: <https://orcid.org/0000-0001-8501-7319>)
Maintainer: Satoshi Kume <satoshi.kume.1984@gmail.com>
