# Default NAMESPACE created by R
# Remove the previous line if you edit this file

# Export all names
exportPattern("^[^.]")

# Import all packages listed as Imports or Depends
import(
  ExperimentHub,
  AnnotationHub,
  markdown,
  rmarkdown,
  EBImage,
  magick,
  magrittr,
  filesstrings,
  animation,
  einsum
)
